/*
 * Created by make_ci.pike
 * on Thu Dec 31 21:22:56 2015
 *
 * Table used for looking up the case of
 * Unicode characters.
 *
 * Henrik Grubbstrm 1999-03-20
 */

{ 0x000000, CIM_NONE, 0x0000, },
{ 0x0000b5, CIM_LOWERDELTA, -0x02e7, },
{ 0x0000b6, CIM_NONE, 0x0000, },
{ 0x0000c0, CIM_CASEBIT, 0x0020, },
{ 0x0000d7, CIM_NONE, 0x0000, },
{ 0x0000d8, CIM_CASEBIT, 0x0020, },
{ 0x0000df, CIM_NONE, 0x0000, },
{ 0x0000e0, CIM_CASEBIT, 0x0020, },
{ 0x0000f7, CIM_NONE, 0x0000, },
{ 0x0000f8, CIM_CASEBIT, 0x0020, },
{ 0x0000ff, CIM_LOWERDELTA, -0x0079, },
{ 0x000100, CIM_CASEBIT, 0x0001, },
{ 0x000130, CIM_UPPERDELTA, -0x00c7, },
{ 0x000131, CIM_LOWERDELTA, 0x00e8, },
{ 0x000132, CIM_CASEBIT, 0x0001, },
{ 0x000138, CIM_NONE, 0x0000, },
{ 0x000139, CIM_CASEBITOFF, 0x0001, },
{ 0x000149, CIM_NONE, 0x0000, },
{ 0x00014a, CIM_CASEBIT, 0x0001, },
{ 0x000178, CIM_UPPERDELTA, -0x0079, },
{ 0x000179, CIM_CASEBITOFF, 0x0001, },
{ 0x00017f, CIM_LOWERDELTA, 0x012c, },
{ 0x000180, CIM_LOWERDELTA, -0x00c3, },
{ 0x000181, CIM_UPPERDELTA, 0x00d2, },
{ 0x000182, CIM_CASEBIT, 0x0001, },
{ 0x000186, CIM_UPPERDELTA, 0x00ce, },
{ 0x000187, CIM_CASEBITOFF, 0x0001, },
{ 0x000189, CIM_UPPERDELTA, 0x00cd, },
{ 0x00018b, CIM_CASEBITOFF, 0x0001, },
{ 0x00018d, CIM_NONE, 0x0000, },
{ 0x00018e, CIM_UPPERDELTA, 0x004f, },
{ 0x00018f, CIM_UPPERDELTA, 0x00ca, },
{ 0x000190, CIM_UPPERDELTA, 0x00cb, },
{ 0x000191, CIM_CASEBITOFF, 0x0001, },
{ 0x000193, CIM_UPPERDELTA, 0x00cd, },
{ 0x000194, CIM_UPPERDELTA, 0x00cf, },
{ 0x000195, CIM_LOWERDELTA, -0x0061, },
{ 0x000196, CIM_UPPERDELTA, 0x00d3, },
{ 0x000197, CIM_UPPERDELTA, 0x00d1, },
{ 0x000198, CIM_CASEBIT, 0x0001, },
{ 0x00019a, CIM_LOWERDELTA, -0x00a3, },
{ 0x00019b, CIM_NONE, 0x0000, },
{ 0x00019c, CIM_UPPERDELTA, 0x00d3, },
{ 0x00019d, CIM_UPPERDELTA, 0x00d5, },
{ 0x00019e, CIM_LOWERDELTA, -0x0082, },
{ 0x00019f, CIM_UPPERDELTA, 0x00d6, },
{ 0x0001a0, CIM_CASEBIT, 0x0001, },
{ 0x0001a6, CIM_UPPERDELTA, 0x00da, },
{ 0x0001a7, CIM_CASEBITOFF, 0x0001, },
{ 0x0001a9, CIM_UPPERDELTA, 0x00da, },
{ 0x0001aa, CIM_NONE, 0x0000, },
{ 0x0001ac, CIM_CASEBIT, 0x0001, },
{ 0x0001ae, CIM_UPPERDELTA, 0x00da, },
{ 0x0001af, CIM_CASEBITOFF, 0x0001, },
{ 0x0001b1, CIM_UPPERDELTA, 0x00d9, },
{ 0x0001b3, CIM_CASEBITOFF, 0x0001, },
{ 0x0001b7, CIM_UPPERDELTA, 0x00db, },
{ 0x0001b8, CIM_CASEBIT, 0x0001, },
{ 0x0001ba, CIM_NONE, 0x0000, },
{ 0x0001bc, CIM_CASEBIT, 0x0001, },
{ 0x0001be, CIM_NONE, 0x0000, },
{ 0x0001bf, CIM_LOWERDELTA, -0x0038, },
{ 0x0001c0, CIM_NONE, 0x0000, },
{ 0x0001c4, CIM_CASEBIT, 0x0002, },
{ 0x0001c5, CIM_CASEBITOFF, 0x0001, },
{ 0x0001c7, CIM_CASEBITOFF, 0x0002, },
{ 0x0001c8, CIM_CASEBIT, 0x0001, },
{ 0x0001ca, CIM_CASEBITOFF, 0x0002, },
{ 0x0001cb, CIM_CASEBITOFF, 0x0001, },
{ 0x0001dd, CIM_LOWERDELTA, 0x004f, },
{ 0x0001de, CIM_CASEBIT, 0x0001, },
{ 0x0001f0, CIM_NONE, 0x0000, },
{ 0x0001f1, CIM_CASEBIT, 0x0002, },
{ 0x0001f2, CIM_CASEBIT, 0x0001, },
{ 0x0001f6, CIM_UPPERDELTA, -0x0061, },
{ 0x0001f7, CIM_UPPERDELTA, -0x0038, },
{ 0x0001f8, CIM_CASEBIT, 0x0001, },
{ 0x000220, CIM_UPPERDELTA, -0x0082, },
{ 0x000221, CIM_NONE, 0x0000, },
{ 0x000222, CIM_CASEBIT, 0x0001, },
{ 0x000234, CIM_NONE, 0x0000, },
{ 0x00023a, CIM_UPPERDELTA, 0x2a2b, },
{ 0x00023b, CIM_CASEBITOFF, 0x0001, },
{ 0x00023d, CIM_UPPERDELTA, -0x00a3, },
{ 0x00023e, CIM_UPPERDELTA, 0x2a28, },
{ 0x00023f, CIM_LOWERDELTA, -0x2a3f, },
{ 0x000241, CIM_CASEBITOFF, 0x0001, },
{ 0x000243, CIM_UPPERDELTA, -0x00c3, },
{ 0x000244, CIM_UPPERDELTA, 0x0045, },
{ 0x000245, CIM_UPPERDELTA, 0x0047, },
{ 0x000246, CIM_CASEBIT, 0x0001, },
{ 0x000250, CIM_LOWERDELTA, -0x2a1f, },
{ 0x000251, CIM_LOWERDELTA, -0x2a1c, },
{ 0x000252, CIM_LOWERDELTA, -0x2a1e, },
{ 0x000253, CIM_LOWERDELTA, 0x00d2, },
{ 0x000254, CIM_LOWERDELTA, 0x00ce, },
{ 0x000255, CIM_NONE, 0x0000, },
{ 0x000256, CIM_LOWERDELTA, 0x00cd, },
{ 0x000258, CIM_NONE, 0x0000, },
{ 0x000259, CIM_LOWERDELTA, 0x00ca, },
{ 0x00025a, CIM_NONE, 0x0000, },
{ 0x00025b, CIM_LOWERDELTA, 0x00cb, },
{ 0x00025c, CIM_LONGLOWERDELTA, -0x254f, },
{ 0x00025d, CIM_NONE, 0x0000, },
{ 0x000260, CIM_LOWERDELTA, 0x00cd, },
{ 0x000261, CIM_LONGLOWERDELTA, -0x254b, },
{ 0x000262, CIM_NONE, 0x0000, },
{ 0x000263, CIM_LOWERDELTA, 0x00cf, },
{ 0x000264, CIM_NONE, 0x0000, },
{ 0x000265, CIM_LONGLOWERDELTA, -0x2528, },
{ 0x000266, CIM_LONGLOWERDELTA, -0x2544, },
{ 0x000267, CIM_NONE, 0x0000, },
{ 0x000268, CIM_LOWERDELTA, 0x00d1, },
{ 0x000269, CIM_LOWERDELTA, 0x00d3, },
{ 0x00026a, CIM_NONE, 0x0000, },
{ 0x00026b, CIM_LOWERDELTA, -0x29f7, },
{ 0x00026c, CIM_LONGLOWERDELTA, -0x2541, },
{ 0x00026d, CIM_NONE, 0x0000, },
{ 0x00026f, CIM_LOWERDELTA, 0x00d3, },
{ 0x000270, CIM_NONE, 0x0000, },
{ 0x000271, CIM_LOWERDELTA, -0x29fd, },
{ 0x000272, CIM_LOWERDELTA, 0x00d5, },
{ 0x000273, CIM_NONE, 0x0000, },
{ 0x000275, CIM_LOWERDELTA, 0x00d6, },
{ 0x000276, CIM_NONE, 0x0000, },
{ 0x00027d, CIM_LOWERDELTA, -0x29e7, },
{ 0x00027e, CIM_NONE, 0x0000, },
{ 0x000280, CIM_LOWERDELTA, 0x00da, },
{ 0x000281, CIM_NONE, 0x0000, },
{ 0x000283, CIM_LOWERDELTA, 0x00da, },
{ 0x000284, CIM_NONE, 0x0000, },
{ 0x000287, CIM_LONGLOWERDELTA, -0x252a, },
{ 0x000288, CIM_LOWERDELTA, 0x00da, },
{ 0x000289, CIM_LOWERDELTA, 0x0045, },
{ 0x00028a, CIM_LOWERDELTA, 0x00d9, },
{ 0x00028c, CIM_LOWERDELTA, 0x0047, },
{ 0x00028d, CIM_NONE, 0x0000, },
{ 0x000292, CIM_LOWERDELTA, 0x00db, },
{ 0x000293, CIM_NONE, 0x0000, },
{ 0x00029d, CIM_LONGLOWERDELTA, -0x2515, },
{ 0x00029e, CIM_LONGLOWERDELTA, -0x2512, },
{ 0x00029f, CIM_NONE, 0x0000, },
{ 0x000345, CIM_LOWERDELTA, -0x0054, },
{ 0x000346, CIM_NONE, 0x0000, },
{ 0x000370, CIM_CASEBIT, 0x0001, },
{ 0x000374, CIM_NONE, 0x0000, },
{ 0x000376, CIM_CASEBIT, 0x0001, },
{ 0x000378, CIM_NONE, 0x0000, },
{ 0x00037b, CIM_LOWERDELTA, -0x0082, },
{ 0x00037e, CIM_NONE, 0x0000, },
{ 0x00037f, CIM_UPPERDELTA, 0x0074, },
{ 0x000380, CIM_NONE, 0x0000, },
{ 0x000386, CIM_UPPERDELTA, 0x0026, },
{ 0x000387, CIM_NONE, 0x0000, },
{ 0x000388, CIM_UPPERDELTA, 0x0025, },
{ 0x00038b, CIM_NONE, 0x0000, },
{ 0x00038c, CIM_CASEBIT, 0x0040, },
{ 0x00038d, CIM_NONE, 0x0000, },
{ 0x00038e, CIM_UPPERDELTA, 0x003f, },
{ 0x000390, CIM_NONE, 0x0000, },
{ 0x000391, CIM_CASEBIT, 0x0020, },
{ 0x0003a0, CIM_CASEBITOFF, 0x0020, },
{ 0x0003a2, CIM_NONE, 0x0000, },
{ 0x0003a3, CIM_CASEBITOFF, 0x0020, },
{ 0x0003ac, CIM_LOWERDELTA, 0x0026, },
{ 0x0003ad, CIM_LOWERDELTA, 0x0025, },
{ 0x0003b0, CIM_NONE, 0x0000, },
{ 0x0003b1, CIM_CASEBIT, 0x0020, },
{ 0x0003c0, CIM_CASEBITOFF, 0x0020, },
{ 0x0003c2, CIM_LOWERDELTA, 0x001f, },
{ 0x0003c3, CIM_CASEBITOFF, 0x0020, },
{ 0x0003cc, CIM_CASEBIT, 0x0040, },
{ 0x0003cd, CIM_LOWERDELTA, 0x003f, },
{ 0x0003cf, CIM_CASEBITOFF, 0x0008, },
{ 0x0003d0, CIM_LOWERDELTA, 0x003e, },
{ 0x0003d1, CIM_LOWERDELTA, 0x0039, },
{ 0x0003d2, CIM_NONE, 0x0000, },
{ 0x0003d5, CIM_LOWERDELTA, 0x002f, },
{ 0x0003d6, CIM_LOWERDELTA, 0x0036, },
{ 0x0003d7, CIM_CASEBITOFF, 0x0008, },
{ 0x0003d8, CIM_CASEBIT, 0x0001, },
{ 0x0003f0, CIM_LOWERDELTA, 0x0056, },
{ 0x0003f1, CIM_LOWERDELTA, 0x0050, },
{ 0x0003f2, CIM_LOWERDELTA, -0x0007, },
{ 0x0003f3, CIM_LOWERDELTA, 0x0074, },
{ 0x0003f4, CIM_UPPERDELTA, -0x003c, },
{ 0x0003f5, CIM_LOWERDELTA, 0x0060, },
{ 0x0003f6, CIM_NONE, 0x0000, },
{ 0x0003f7, CIM_CASEBITOFF, 0x0001, },
{ 0x0003f9, CIM_UPPERDELTA, -0x0007, },
{ 0x0003fa, CIM_CASEBIT, 0x0001, },
{ 0x0003fc, CIM_NONE, 0x0000, },
{ 0x0003fd, CIM_UPPERDELTA, -0x0082, },
{ 0x000400, CIM_UPPERDELTA, 0x0050, },
{ 0x000410, CIM_CASEBIT, 0x0020, },
{ 0x000420, CIM_CASEBITOFF, 0x0020, },
{ 0x000430, CIM_CASEBIT, 0x0020, },
{ 0x000440, CIM_CASEBITOFF, 0x0020, },
{ 0x000450, CIM_LOWERDELTA, 0x0050, },
{ 0x000460, CIM_CASEBIT, 0x0001, },
{ 0x000482, CIM_NONE, 0x0000, },
{ 0x00048a, CIM_CASEBIT, 0x0001, },
{ 0x0004c0, CIM_UPPERDELTA, 0x000f, },
{ 0x0004c1, CIM_CASEBITOFF, 0x0001, },
{ 0x0004cf, CIM_LOWERDELTA, 0x000f, },
{ 0x0004d0, CIM_CASEBIT, 0x0001, },
{ 0x000530, CIM_NONE, 0x0000, },
{ 0x000531, CIM_UPPERDELTA, 0x0030, },
{ 0x000557, CIM_NONE, 0x0000, },
{ 0x000561, CIM_LOWERDELTA, 0x0030, },
{ 0x000587, CIM_NONE, 0x0000, },
{ 0x0010a0, CIM_UPPERDELTA, 0x1c60, },
{ 0x0010c6, CIM_NONE, 0x0000, },
{ 0x0010c7, CIM_UPPERDELTA, 0x1c60, },
{ 0x0010c8, CIM_NONE, 0x0000, },
{ 0x0010cd, CIM_UPPERDELTA, 0x1c60, },
{ 0x0010ce, CIM_NONE, 0x0000, },
{ 0x0013a0, CIM_LONGUPPERDELTA, 0x17d1, },
{ 0x0013f0, CIM_CASEBIT, 0x0008, },
{ 0x0013f6, CIM_NONE, 0x0000, },
{ 0x0013f8, CIM_CASEBIT, 0x0008, },
{ 0x0013fe, CIM_NONE, 0x0000, },
{ 0x001d79, CIM_LONGLOWERDELTA, -0x0a04, },
{ 0x001d7a, CIM_NONE, 0x0000, },
{ 0x001d7d, CIM_LOWERDELTA, -0x0ee6, },
{ 0x001d7e, CIM_NONE, 0x0000, },
{ 0x001e00, CIM_CASEBIT, 0x0001, },
{ 0x001e96, CIM_NONE, 0x0000, },
{ 0x001e9b, CIM_LOWERDELTA, 0x003b, },
{ 0x001e9c, CIM_NONE, 0x0000, },
{ 0x001e9e, CIM_UPPERDELTA, -0x1dbf, },
{ 0x001e9f, CIM_NONE, 0x0000, },
{ 0x001ea0, CIM_CASEBIT, 0x0001, },
{ 0x001f00, CIM_LOWERDELTA, -0x0008, },
{ 0x001f08, CIM_UPPERDELTA, -0x0008, },
{ 0x001f10, CIM_LOWERDELTA, -0x0008, },
{ 0x001f16, CIM_NONE, 0x0000, },
{ 0x001f18, CIM_UPPERDELTA, -0x0008, },
{ 0x001f1e, CIM_NONE, 0x0000, },
{ 0x001f20, CIM_LOWERDELTA, -0x0008, },
{ 0x001f28, CIM_UPPERDELTA, -0x0008, },
{ 0x001f30, CIM_LOWERDELTA, -0x0008, },
{ 0x001f38, CIM_UPPERDELTA, -0x0008, },
{ 0x001f40, CIM_LOWERDELTA, -0x0008, },
{ 0x001f46, CIM_NONE, 0x0000, },
{ 0x001f48, CIM_UPPERDELTA, -0x0008, },
{ 0x001f4e, CIM_NONE, 0x0000, },
{ 0x001f51, CIM_LOWERDELTA, -0x0008, },
{ 0x001f52, CIM_NONE, 0x0000, },
{ 0x001f53, CIM_LOWERDELTA, -0x0008, },
{ 0x001f54, CIM_NONE, 0x0000, },
{ 0x001f55, CIM_LOWERDELTA, -0x0008, },
{ 0x001f56, CIM_NONE, 0x0000, },
{ 0x001f57, CIM_LOWERDELTA, -0x0008, },
{ 0x001f58, CIM_NONE, 0x0000, },
{ 0x001f59, CIM_UPPERDELTA, -0x0008, },
{ 0x001f5a, CIM_NONE, 0x0000, },
{ 0x001f5b, CIM_UPPERDELTA, -0x0008, },
{ 0x001f5c, CIM_NONE, 0x0000, },
{ 0x001f5d, CIM_UPPERDELTA, -0x0008, },
{ 0x001f5e, CIM_NONE, 0x0000, },
{ 0x001f5f, CIM_UPPERDELTA, -0x0008, },
{ 0x001f60, CIM_LOWERDELTA, -0x0008, },
{ 0x001f68, CIM_UPPERDELTA, -0x0008, },
{ 0x001f70, CIM_LOWERDELTA, -0x004a, },
{ 0x001f72, CIM_LOWERDELTA, -0x0056, },
{ 0x001f76, CIM_LOWERDELTA, -0x0064, },
{ 0x001f78, CIM_LOWERDELTA, -0x0080, },
{ 0x001f7a, CIM_LOWERDELTA, -0x0070, },
{ 0x001f7c, CIM_LOWERDELTA, -0x007e, },
{ 0x001f7e, CIM_NONE, 0x0000, },
{ 0x001f80, CIM_LOWERDELTA, -0x0008, },
{ 0x001f88, CIM_UPPERDELTA, -0x0008, },
{ 0x001f90, CIM_LOWERDELTA, -0x0008, },
{ 0x001f98, CIM_UPPERDELTA, -0x0008, },
{ 0x001fa0, CIM_LOWERDELTA, -0x0008, },
{ 0x001fa8, CIM_UPPERDELTA, -0x0008, },
{ 0x001fb0, CIM_LOWERDELTA, -0x0008, },
{ 0x001fb2, CIM_NONE, 0x0000, },
{ 0x001fb3, CIM_LOWERDELTA, -0x0009, },
{ 0x001fb4, CIM_NONE, 0x0000, },
{ 0x001fb8, CIM_UPPERDELTA, -0x0008, },
{ 0x001fba, CIM_UPPERDELTA, -0x004a, },
{ 0x001fbc, CIM_UPPERDELTA, -0x0009, },
{ 0x001fbd, CIM_NONE, 0x0000, },
{ 0x001fbe, CIM_LOWERDELTA, 0x1c25, },
{ 0x001fbf, CIM_NONE, 0x0000, },
{ 0x001fc3, CIM_LOWERDELTA, -0x0009, },
{ 0x001fc4, CIM_NONE, 0x0000, },
{ 0x001fc8, CIM_UPPERDELTA, -0x0056, },
{ 0x001fcc, CIM_UPPERDELTA, -0x0009, },
{ 0x001fcd, CIM_NONE, 0x0000, },
{ 0x001fd0, CIM_LOWERDELTA, -0x0008, },
{ 0x001fd2, CIM_NONE, 0x0000, },
{ 0x001fd8, CIM_UPPERDELTA, -0x0008, },
{ 0x001fda, CIM_UPPERDELTA, -0x0064, },
{ 0x001fdc, CIM_NONE, 0x0000, },
{ 0x001fe0, CIM_LOWERDELTA, -0x0008, },
{ 0x001fe2, CIM_NONE, 0x0000, },
{ 0x001fe5, CIM_LOWERDELTA, -0x0007, },
{ 0x001fe6, CIM_NONE, 0x0000, },
{ 0x001fe8, CIM_UPPERDELTA, -0x0008, },
{ 0x001fea, CIM_UPPERDELTA, -0x0070, },
{ 0x001fec, CIM_UPPERDELTA, -0x0007, },
{ 0x001fed, CIM_NONE, 0x0000, },
{ 0x001ff3, CIM_LOWERDELTA, -0x0009, },
{ 0x001ff4, CIM_NONE, 0x0000, },
{ 0x001ff8, CIM_UPPERDELTA, -0x0080, },
{ 0x001ffa, CIM_UPPERDELTA, -0x007e, },
{ 0x001ffc, CIM_UPPERDELTA, -0x0009, },
{ 0x001ffd, CIM_NONE, 0x0000, },
{ 0x002126, CIM_UPPERDELTA, -0x1d5d, },
{ 0x002127, CIM_NONE, 0x0000, },
{ 0x00212a, CIM_UPPERDELTA, -0x20bf, },
{ 0x00212b, CIM_UPPERDELTA, -0x2046, },
{ 0x00212c, CIM_NONE, 0x0000, },
{ 0x002132, CIM_UPPERDELTA, 0x001c, },
{ 0x002133, CIM_NONE, 0x0000, },
{ 0x00214e, CIM_LOWERDELTA, 0x001c, },
{ 0x00214f, CIM_NONE, 0x0000, },
{ 0x002160, CIM_CASEBIT, 0x0010, },
{ 0x002180, CIM_NONE, 0x0000, },
{ 0x002183, CIM_CASEBITOFF, 0x0001, },
{ 0x002185, CIM_NONE, 0x0000, },
{ 0x0024b6, CIM_UPPERDELTA, 0x001a, },
{ 0x0024d0, CIM_LOWERDELTA, 0x001a, },
{ 0x0024ea, CIM_NONE, 0x0000, },
{ 0x002c00, CIM_UPPERDELTA, 0x0030, },
{ 0x002c2f, CIM_NONE, 0x0000, },
{ 0x002c30, CIM_LOWERDELTA, 0x0030, },
{ 0x002c5f, CIM_NONE, 0x0000, },
{ 0x002c60, CIM_CASEBIT, 0x0001, },
{ 0x002c62, CIM_UPPERDELTA, -0x29f7, },
{ 0x002c63, CIM_UPPERDELTA, -0x0ee6, },
{ 0x002c64, CIM_UPPERDELTA, -0x29e7, },
{ 0x002c65, CIM_LOWERDELTA, 0x2a2b, },
{ 0x002c66, CIM_LOWERDELTA, 0x2a28, },
{ 0x002c67, CIM_CASEBITOFF, 0x0001, },
{ 0x002c6d, CIM_UPPERDELTA, -0x2a1c, },
{ 0x002c6e, CIM_UPPERDELTA, -0x29fd, },
{ 0x002c6f, CIM_UPPERDELTA, -0x2a1f, },
{ 0x002c70, CIM_UPPERDELTA, -0x2a1e, },
{ 0x002c71, CIM_NONE, 0x0000, },
{ 0x002c72, CIM_CASEBIT, 0x0001, },
{ 0x002c74, CIM_NONE, 0x0000, },
{ 0x002c75, CIM_CASEBITOFF, 0x0001, },
{ 0x002c77, CIM_NONE, 0x0000, },
{ 0x002c7e, CIM_UPPERDELTA, -0x2a3f, },
{ 0x002c80, CIM_CASEBIT, 0x0001, },
{ 0x002ce4, CIM_NONE, 0x0000, },
{ 0x002ceb, CIM_CASEBITOFF, 0x0001, },
{ 0x002cef, CIM_NONE, 0x0000, },
{ 0x002cf2, CIM_CASEBIT, 0x0001, },
{ 0x002cf4, CIM_NONE, 0x0000, },
{ 0x002d00, CIM_LOWERDELTA, 0x1c60, },
{ 0x002d26, CIM_NONE, 0x0000, },
{ 0x002d27, CIM_LOWERDELTA, 0x1c60, },
{ 0x002d28, CIM_NONE, 0x0000, },
{ 0x002d2d, CIM_LOWERDELTA, 0x1c60, },
{ 0x002d2e, CIM_NONE, 0x0000, },
{ 0x00a640, CIM_CASEBIT, 0x0001, },
{ 0x00a66e, CIM_NONE, 0x0000, },
{ 0x00a680, CIM_CASEBIT, 0x0001, },
{ 0x00a69c, CIM_NONE, 0x0000, },
{ 0x00a722, CIM_CASEBIT, 0x0001, },
{ 0x00a730, CIM_NONE, 0x0000, },
{ 0x00a732, CIM_CASEBIT, 0x0001, },
{ 0x00a770, CIM_NONE, 0x0000, },
{ 0x00a779, CIM_CASEBITOFF, 0x0001, },
{ 0x00a77d, CIM_LONGUPPERDELTA, -0x0a04, },
{ 0x00a77e, CIM_CASEBIT, 0x0001, },
{ 0x00a788, CIM_NONE, 0x0000, },
{ 0x00a78b, CIM_CASEBITOFF, 0x0001, },
{ 0x00a78d, CIM_LONGUPPERDELTA, -0x2528, },
{ 0x00a78e, CIM_NONE, 0x0000, },
{ 0x00a790, CIM_CASEBIT, 0x0001, },
{ 0x00a794, CIM_NONE, 0x0000, },
{ 0x00a796, CIM_CASEBIT, 0x0001, },
{ 0x00a7aa, CIM_LONGUPPERDELTA, -0x2544, },
{ 0x00a7ab, CIM_LONGUPPERDELTA, -0x254f, },
{ 0x00a7ac, CIM_LONGUPPERDELTA, -0x254b, },
{ 0x00a7ad, CIM_LONGUPPERDELTA, -0x2541, },
{ 0x00a7ae, CIM_NONE, 0x0000, },
{ 0x00a7b0, CIM_LONGUPPERDELTA, -0x2512, },
{ 0x00a7b1, CIM_LONGUPPERDELTA, -0x252a, },
{ 0x00a7b2, CIM_LONGUPPERDELTA, -0x2515, },
{ 0x00a7b3, CIM_UPPERDELTA, 0x03a0, },
{ 0x00a7b4, CIM_CASEBIT, 0x0001, },
{ 0x00a7b8, CIM_NONE, 0x0000, },
{ 0x00ab53, CIM_LOWERDELTA, 0x03a0, },
{ 0x00ab54, CIM_NONE, 0x0000, },
{ 0x00ab70, CIM_LONGLOWERDELTA, 0x17d1, },
{ 0x00abc0, CIM_NONE, 0x0000, },
{ 0x00ff21, CIM_CASEBITOFF, 0x0020, },
{ 0x00ff3b, CIM_NONE, 0x0000, },
{ 0x00ff41, CIM_CASEBITOFF, 0x0020, },
{ 0x00ff5b, CIM_NONE, 0x0000, },
{ 0x010400, CIM_UPPERDELTA, 0x0028, },
{ 0x010428, CIM_LOWERDELTA, 0x0028, },
{ 0x010450, CIM_NONE, 0x0000, },
{ 0x010c80, CIM_CASEBIT, 0x0040, },
{ 0x010cb3, CIM_NONE, 0x0000, },
{ 0x010cc0, CIM_CASEBIT, 0x0040, },
{ 0x010cf3, CIM_NONE, 0x0000, },
{ 0x0118a0, CIM_CASEBITOFF, 0x0020, },
{ 0x0118e0, CIM_NONE, 0x0000, },


#define CASE_INFO_SHIFT0_HIGH 0x000b
